package com.ssj.dao.weixin.grword.dao;

import java.util.List;
import java.util.Map;

public interface ReadQueryDao {
	
	
	//查询当前isbn13一共有多少题目
	Map<String,Object> findSubjectByIsbn13(String isbn13);
	
	
	//查询用户当前isbn13答到那题目
	Map<String,Object> findAnswerByUserId(String userId, String isbn13, String scoreId);
	
	
	//查询当前isbn13,的下一题
	Map<String,Object> findSubjectByIsbn13AndSort(String isbn13, Integer sort);
	
	//
	List<Map<String, Object> > findBookByUserIdAndLevel(String userId, Integer level, Integer userGr, Integer size);
	 
	
	List<Map<String, Object>> findBookByUserIdAndLevelSuccess(String userId);
	
	List<Map<String, Object>> findSubjectByIsbn13Page(String Isbn13);
	
	List<Map<String,Object>> findAnswerByUserIdPage(String userId, String isbn13, String scoreId);
	 

    
}
